@@ -23,9 +23,9 @@ Module handles clip effects editing logic and gui
 """
 
 
-
+from gi.repository import GLib
 from gi.repository import Gtk
-
+import time
 
 import dnd
 import edit
@@ -53,6 +53,16 @@ block_changed_update = False # Used to block unwanted callback update from "chan
 # Used to update kfeditors with external tline frame position changes
 keyframe_editor_widgets = []
 
+# Filter stack DND requires some state info to be maintained to make sure that it's only done when certain events
+# happen in a certain sequence.
+NOT_ON = 0
+MOUSE_PRESS_DONE = 1
+INSERT_DONE = 2
+stack_dnd_state = NOT_ON
+stack_dnd_event_time = 0.0
+stack_dnd_event_info = None
+
+filters_notebook_index = 2
 
 def get_clip_effects_editor_panel(group_combo_box, effects_list_view):
     """
@@ -132,7 +142,7 @@ def set_clip(new_clip, new_track, new_index):
     set_enabled(True)
     update_stack_view()
     effect_selection_changed() # This may get called twice
-    gui.middle_notebook.set_current_page(2) # 2 == index of clipeditor page in notebook
+    gui.middle_notebook.set_current_page(filters_notebook_index) # 2 == index of clipeditor page in notebook
 
 def clip_removed_during_edit(removed_clip):
     """
@@ -165,12 +175,24 @@ def filter_stack_button_press(treeview, event):
 
 def _filter_stack_menu_item_selected(widget, data):
     item_id, row, treeview = data
-    # Toggle filter active state
+
     if item_id == "toggle":
         toggle_filter_active(row)
     if item_id == "reset":
         reset_filter_values()
-
+    if item_id == "moveup":
+        delete_row = row
+        insert_row = row + 2
+        if insert_row > len(clip.filters):
+            insert_row = len(clip.filters)
+        do_stack_move(insert_row, delete_row)
+    if item_id == "movedown":
+        delete_row = row + 1
+        insert_row = row - 1
+        if insert_row < 0:
+            insert_row = 0
+        do_stack_move(insert_row, delete_row)
+        
 def _quit_editing_clip_clicked(): # this is a button callback
     clear_clip()
 
@@ -200,8 +222,10 @@ def create_widgets():
     widgets.exit_button.connect("clicked", lambda w: _quit_editing_clip_clicked())
     widgets.exit_button.set_tooltip_text(_("Quit editing Clip in editor"))
 
-    widgets.effect_stack_view = guicomponents.FilterSwitchListView(lambda ts: effect_selection_changed(), toggle_filter_active)
-    dnd.connect_stack_treeview(widgets.effect_stack_view)
+    widgets.effect_stack_view = guicomponents.FilterSwitchListView(lambda ts: effect_selection_changed(), 
+                                                                   toggle_filter_active, dnd_row_deleted, dnd_row_inserted)
+                                                                   
+    widgets.effect_stack_view.treeview.connect("button-press-event", lambda w,e, wtf: stack_view_pressed(), None)
     gui.effect_stack_list_view = widgets.effect_stack_view
     
     widgets.value_edit_box = Gtk.VBox()
@@ -349,7 +373,55 @@ def toggle_filter_active(row, update_stack_view=True):
     filter_object.update_mlt_disabled_value()
     if update_stack_view == True:
         update_stack_view_changed_blocked()
+
+def dnd_row_deleted(model, path):
+    now = time.time()
+    global stack_dnd_state, stack_dnd_event_time, stack_dnd_event_info
+    if stack_dnd_state == INSERT_DONE:
+        if (now - stack_dnd_event_time) < 0.1:
+            stack_dnd_state = NOT_ON
+            insert_row = int(stack_dnd_event_info)
+            delete_row = int(path.to_string())
+            stack_dnd_event_info = (insert_row, delete_row)
+            # Because of dnd is gtk thing for some internal reason it needs to complete before we go on
+            # touching storemodel again with .clear() or it dies in gtktreeviewaccessible.c
+            GLib.idle_add(do_dnd_stack_move)
+        else:
+            stack_dnd_state = NOT_ON
+    else:
+        stack_dnd_state = NOT_ON
+        
+def dnd_row_inserted(model, path, tree_iter):
+    global stack_dnd_state, stack_dnd_event_time, stack_dnd_event_info
+    if stack_dnd_state == MOUSE_PRESS_DONE:
+        stack_dnd_state = INSERT_DONE
+        stack_dnd_event_time = time.time()
+        stack_dnd_event_info = path.to_string()
+    else:
+        stack_dnd_state = NOT_ON
+
+def do_dnd_stack_move():
+    insert, delete_row = stack_dnd_event_info
+    do_stack_move(insert, delete_row)
+    
+def do_stack_move(insert_row, delete_row):
+    if abs(insert_row - delete_row) < 2: # filter was dropped on its previous place or cannot moved further up or down
+        return
+    
+    # The insert insert_row and delete_row values are rows we get when listening 
+    # "row-deleted" and "row-inserted" events after setting treeview "reorderable"
+    # Dnd is detected by order and timing of these events together with mouse press event
+    data = {"clip":clip,
+            "insert_index":insert_row,
+            "delete_index":delete_row,
+            "filter_edit_done_func":filter_edit_done}
+    action = edit.move_filter_action(data)
+    action.do_edit()
             
+def stack_view_pressed():
+    global stack_dnd_state
+    stack_dnd_state = MOUSE_PRESS_DONE
+
 def effect_selection_changed():
     global keyframe_editor_widgets
 
@@ -490,5 +562,7 @@ def display_kfeditors_tline_frame(frame):
         kf_widget.display_tline_frame(frame)
 
 def update_kfeditors_positions():
+    if clip == None:
+        return
     for kf_widget in keyframe_editor_widgets:
         kf_widget.update_clip_pos()
