@@ -71,10 +71,9 @@ def new_project_dialog(callback):
     profiles_vbox = guiutils.get_vbox([profile_select,profile_info_box], False)
     profiles_frame = panels.get_named_frame(_("Profile"), profiles_vbox)
 
-    tracks_combo, tracks_combo_values_list = guicomponents.get_track_counts_combo_and_values_list()
-    tracks_select = panels.get_two_column_box(Gtk.Label(label=_("Number of tracks:")),
-                                               tracks_combo, 250)
-    tracks_vbox = guiutils.get_vbox([tracks_select], False)
+    tracks_select = guicomponents.TracksNumbersSelect(5, 4)
+    
+    tracks_vbox = guiutils.get_vbox([tracks_select.widget], False)
 
     tracks_frame = panels.get_named_frame(_("Tracks"), tracks_vbox)
 
@@ -84,8 +83,7 @@ def new_project_dialog(callback):
     dialogutils.set_outer_margins(dialog.vbox)
     dialog.vbox.pack_start(alignment, True, True, 0)
     _default_behaviour(dialog)
-    dialog.connect('response', callback, out_profile_combo, tracks_combo,
-                   tracks_combo_values_list)
+    dialog.connect('response', callback, out_profile_combo, tracks_select)
                    
     out_profile_combo.connect('changed', lambda w: _new_project_profile_changed(w, profile_info_box))
     dialog.show_all()
@@ -408,7 +406,7 @@ def about_dialog(parent_window):
 
     img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
     flow_label = Gtk.Label(label="Flowblade Movie Editor")
-    ver_label = Gtk.Label(label="1.10.0")
+    ver_label = Gtk.Label(label="1.12.0")
     janne_label = Gtk.Label(label="Copyright 2016 Janne Liljeblad and contributors")
     page_label = Gtk.Label(label="Project page: https://github.com/jliljebl/flowblade")
     flow_label.modify_font(Pango.FontDescription("sans bold 14"))
@@ -456,6 +454,44 @@ def about_dialog(parent_window):
     alignment3 = dialogutils.get_default_alignment(license_view)
     alignment3.set_size_request(450, 370)
 
+    lead_label = Gtk.Label(label="Lead Developer:")
+    lead_label.modify_font(Pango.FontDescription("sans bold 12"))
+    lead_info = Gtk.Label(label="Janne Liljeblad")
+    developers_label = Gtk.Label("Developers:")
+    developers_label.modify_font(Pango.FontDescription("sans bold 12"))
+
+    devs_file = open(respaths.DEVELOPERS_DOC)
+    devs_text = devs_file.read()
+    devs_info = Gtk.Label(label=devs_text)
+
+    contributos_label = Gtk.Label(label="Contributors:")
+    contributos_label.modify_font(Pango.FontDescription("sans bold 12"))
+    
+    contributors_file = open(respaths.CONTRIBUTORS_DOC)
+    contributors_text = contributors_file.read()
+
+    contributors_view = Gtk.TextView()
+    contributors_view.set_editable(False)
+    contributors_view.set_pixels_above_lines(2)
+    contributors_view.set_left_margin(2)
+    contributors_view.set_wrap_mode(Gtk.WrapMode.WORD)
+    contributors_view.get_buffer().set_text(contributors_text)
+    guiutils.set_margins(contributors_view, 0, 0, 30, 30)
+    
+    vbox3 = Gtk.VBox(False, 4)
+    vbox3.pack_start(guiutils.get_pad_label(30, 12), False, False, 0)
+    vbox3.pack_start(lead_label, False, False, 0)
+    vbox3.pack_start(lead_info, False, False, 0)
+    vbox3.pack_start(guiutils.get_pad_label(30, 22), False, False, 0)
+    vbox3.pack_start(developers_label, False, False, 0)
+    vbox3.pack_start(guiutils.get_centered_box([devs_info]), False, False, 0)
+    vbox3.pack_start(guiutils.get_pad_label(30, 22), False, False, 0)
+    vbox3.pack_start(contributos_label, False, False, 0)
+    vbox3.pack_start(contributors_view, False, False, 0)
+    
+    alignment5 = dialogutils.get_default_alignment(vbox3)
+    alignment5.set_size_request(450, 370)
+    
     translations_view = guicomponents.get_translations_scroll_widget((450, 370))
     alignment4 = dialogutils.get_default_alignment(translations_view)
     alignment4.set_size_request(450, 370)
@@ -465,6 +501,7 @@ def about_dialog(parent_window):
     notebook.append_page(alignment, Gtk.Label(label=_("Application")))
     notebook.append_page(alignment2, Gtk.Label(label=_("Thanks")))
     notebook.append_page(alignment3, Gtk.Label(label=_("License")))
+    notebook.append_page(alignment5, Gtk.Label(label=_("Developers")))
     notebook.append_page(alignment4, Gtk.Label(label=_("Translations")))
     guiutils.set_margins(notebook, 6, 6, 6, 0)
 
@@ -811,11 +848,9 @@ def tracks_count_change_dialog(callback):
                         Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
                         (_("Cancel").encode('utf-8'), Gtk.ResponseType.REJECT,
                         _("Change Tracks").encode('utf-8'), Gtk.ResponseType.ACCEPT))
-
-    tracks_combo, tracks_combo_values_list = guicomponents.get_track_counts_combo_and_values_list()
-    tracks_select = panels.get_two_column_box(Gtk.Label(label=_("New Number of Tracks:")),
-                                               tracks_combo,
-                                               250)
+    
+    tracks_select = guicomponents.TracksNumbersSelect(5, 4)
+        
     info_text = _("Please note:\n") + \
                 u"\u2022" + _(" It is recommended that you save Project before completing this operation\n") + \
                 u"\u2022" + _(" There is no Undo for this operation\n") + \
@@ -830,14 +865,14 @@ def tracks_count_change_dialog(callback):
     tracks_vbox = Gtk.VBox(False, 2)
     tracks_vbox.pack_start(info_box, False, False, 0)
     tracks_vbox.pack_start(pad, False, False, 0)
-    tracks_vbox.pack_start(tracks_select, False, False, 0)
+    tracks_vbox.pack_start(tracks_select.widget, False, False, 0)
 
     alignment = dialogutils.get_alignment2(tracks_vbox)
 
     dialog.vbox.pack_start(alignment, True, True, 0)
     dialogutils.set_outer_margins(dialog.vbox)
     _default_behaviour(dialog)
-    dialog.connect('response', callback, tracks_combo)
+    dialog.connect('response', callback, tracks_select)
     dialog.show_all()
 
 def new_sequence_dialog(callback, default_name):
@@ -854,12 +889,9 @@ def new_sequence_dialog(callback, default_name):
     name_select = panels.get_two_column_box(Gtk.Label(label=_("Sequence Name:")),
                                                name_entry,
                                                250)
-
-    tracks_combo, tracks_combo_values_list = guicomponents.get_track_counts_combo_and_values_list()
-    tracks_select = panels.get_two_column_box(Gtk.Label(label=_("Number of Tracks:")),
-                                               tracks_combo,
-                                               250)
-
+   
+    tracks_select = guicomponents.TracksNumbersSelect(5, 4)
+    
     open_check = Gtk.CheckButton()
     open_check.set_active(True)
     open_label = Gtk.Label(label=_("Open For Editing:"))
@@ -871,7 +903,8 @@ def new_sequence_dialog(callback, default_name):
 
     tracks_vbox = Gtk.VBox(False, 2)
     tracks_vbox.pack_start(name_select, False, False, 0)
-    tracks_vbox.pack_start(tracks_select, False, False, 0)
+    tracks_vbox.pack_start(guiutils.get_pad_label(12, 2), False, False, 0)
+    tracks_vbox.pack_start(tracks_select.widget, False, False, 0)
     tracks_vbox.pack_start(guiutils.get_pad_label(12, 12), False, False, 0)
     tracks_vbox.pack_start(open_hbox, False, False, 0)
 
@@ -880,7 +913,7 @@ def new_sequence_dialog(callback, default_name):
     dialog.vbox.pack_start(alignment, True, True, 0)
     dialogutils.set_outer_margins(dialog.vbox)
     _default_behaviour(dialog)
-    dialog.connect('response', callback, (name_entry, tracks_combo, open_check))
+    dialog.connect('response', callback, (name_entry, tracks_select, open_check))
     dialog.show_all()
 
 def new_media_name_dialog(callback, media_file):
@@ -1113,7 +1146,8 @@ def keyboard_shortcuts_dialog(parent_window):
     tline_vbox.pack_start(_get_kb_row("M", _("Add Mark")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Control + C"), _("Copy Clips")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Control + V"), _("Paste Clips")), False, False, 0)
-    tline_vbox.pack_start(_get_kb_row(_("R"), _("Resync selected Clip or Compositor")), False, False, 0)
+    tline_vbox.pack_start(_get_kb_row(_("R"), _("Trim Tool Ripple Mode On/Off")), False, False, 0)
+    tline_vbox.pack_start(_get_kb_row(_("S"), _("Resync selected Clip or Compositor")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("G"), _("Log Marked Clip Range")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Left Arrow "), _("Prev Frame Trim Edit")), False, False, 0)
     tline_vbox.pack_start(_get_kb_row(_("Right Arrow"), _("Next Frame Trim Edit")), False, False, 0)
@@ -1134,6 +1168,7 @@ def keyboard_shortcuts_dialog(parent_window):
     play_vbox.pack_start(_get_kb_row(_("Up Arrow"), _("Next Edit/Mark")), False, False, 0)
     play_vbox.pack_start(_get_kb_row(_("Down Arrow"), _("Prev Edit/Mark")), False, False, 0)
     play_vbox.pack_start(_get_kb_row(_("HOME"), _("Go To Start")), False, False, 0)
+    play_vbox.pack_start(_get_kb_row(_("END"), _("Go To End")), False, False, 0)
     play_vbox.pack_start(_get_kb_row(_("Shift + I"), _("To Mark In")), False, False, 0)
     play_vbox.pack_start(_get_kb_row(_("Shift + O"), _("To Mark Out")), False, False, 0)
     play = guiutils.get_named_frame(_("Playback"), play_vbox)
@@ -1145,13 +1180,17 @@ def keyboard_shortcuts_dialog(parent_window):
     tools_vbox.pack_start(_get_kb_row("4", _("Roll")), False, False, 0)
     tools_vbox.pack_start(_get_kb_row("5", _("Slip")), False, False, 0)
     tools_vbox.pack_start(_get_kb_row("6", _("Spacer")), False, False, 0)
+    tools_vbox.pack_start(_get_kb_row("7", _("Box")), False, False, 0)
+    tools_vbox.pack_start(_get_kb_row(_("R"), _("Trim Tool Ripple Mode On/Off")), False, False, 0)
     tools = guiutils.get_named_frame(_("Tools"), tools_vbox)
 
     geom_vbox = Gtk.VBox()
-    geom_vbox.pack_start(_get_kb_row(_("Left Arrow "), _("Move Source Video Left")), False, False, 0)
-    geom_vbox.pack_start(_get_kb_row(_("Right Arrow"), _("Move Source Video Right")), False, False, 0)
-    geom_vbox.pack_start(_get_kb_row(_("Up Arrow"), _("Move Source Video Up")), False, False, 0)
-    geom_vbox.pack_start(_get_kb_row(_("Down Arrow"), _("Move Source Video Down")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Left Arrow "), _("Move Source Video Left 1px")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Right Arrow"), _("Move Source Video Right 1px")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Up Arrow"), _("Move Source Video Up 1px")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Down Arrow"), _("Move Source Video Down 1px")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Control + Arrow"), _("Move Source Video 10px")), False, False, 0)
+    geom_vbox.pack_start(_get_kb_row(_("Control + Mouse Drag"), _("Keep Aspect Ratio in Affine Blend scaling")), False, False, 0) 
     geom_vbox.pack_start(_get_kb_row(_("Shift"), _("Snap to X or Y of drag start point")), False, False, 0)
     geom = guiutils.get_named_frame(_("Geometry Editor"), geom_vbox)
 
