@@ -25,6 +25,7 @@ and sequence state changes as output.
 Edits, undos and redos are done by creating and calling methods on these 
 EditAction objects and placing them on the undo/redo stack.
 """
+
 import audiowaveform
 import appconsts
 import compositeeditor
@@ -937,7 +938,63 @@ def _overwrite_move_redo(self):
     # HACK, see EditAction for details
     self.turn_on_stop_for_edit = True
 
-      
+
+#----------------- BOX OVERWRITE MOVE
+# "box_selection_data","delta"
+# Lifts clips from track and overwrites part of track with them for multple tracks
+# Move  compositors contained by selection too.
+def box_overwrite_move_action(data):
+    action = EditAction(_box_overwrite_move_undo, _box_overwrite_move_redo, data)
+    action.turn_on_stop_for_edit = True
+    return action
+
+def _box_overwrite_move_undo(self):
+    
+    # Do track move edits
+    for move_data in self.track_moves:
+        action_object = utils.EmptyClass
+        action_object.__dict__.update(move_data)
+
+        _overwrite_move_undo(action_object)
+
+    # Move compositors
+    for comp in self.box_selection_data.selected_compositors:
+        comp.move(-self.delta)
+        
+def _box_overwrite_move_redo(self):
+    # Create data for track overwite moves
+    if not hasattr(self, "track_moves"):
+        self.track_moves = []
+        for track_selection in self.box_selection_data.track_selections:
+            if track_selection.range_frame_in != -1:
+                track_move_data = {"track":current_sequence().tracks[track_selection.track_id],
+                                    "over_in":track_selection.range_frame_in + self.delta,
+                                    "over_out":track_selection.range_frame_out + self.delta,
+                                    "selected_range_in":track_selection.selected_range_in,
+                                    "selected_range_out":track_selection.selected_range_out,
+                                    "move_edit_done_func":None}
+
+                self.track_moves.append(track_move_data)
+
+    else:
+        # This may not be necessery...but its going in to make sure move_data is always same
+        for move_data in self.track_moves:
+            move_data.pop("removed_clips")
+
+    # Do track move edits
+    for move_data in self.track_moves:
+        action_object = utils.EmptyClass
+        action_object.__dict__.update(move_data)
+
+        _overwrite_move_redo(action_object)
+        
+        # Copy data created in _overwrite_move_redo() that is needed in _overwrite_move_undo
+        move_data.update(action_object.__dict__)
+                
+    # Move compositors
+    for comp in self.box_selection_data.selected_compositors:
+        comp.move(self.delta)
+
 #----------------- MULTITRACK OVERWRITE MOVE
 # "track","to_track","over_in","over_out","selected_range_in"
 # "selected_range_out","move_edit_done_func"
@@ -1120,6 +1177,180 @@ def _get_tracks_compositors_list():
     
     return tracks_list
 
+#-------------------------------------------- RIPPLE TRIM END
+# "track","clip","index","edit_delta","first_do","multi_data"
+# self.multi_data is trimmodes.RippleData
+def ripple_trim_end_action(data):
+    action = EditAction(_ripple_trim_end_undo, _ripple_trim_end_redo, data)
+    action.exit_active_trimmode_on_edit = False
+    action.update_hidden_track_blank = False
+    return action
+
+def _ripple_trim_end_undo(self):
+    _remove_clip(self.track, self.index)
+    _insert_clip(self.track, self.clip, self.index,
+                 self.clip.clip_in, self.clip.clip_out - self.edit_delta)
+    
+    _ripple_trim_blanks_undo(self)
+        
+def _ripple_trim_end_redo(self):
+    _remove_clip(self.track, self.index)
+    _insert_clip(self.track, self.clip, self.index,
+                 self.clip.clip_in, self.clip.clip_out + self.edit_delta)
+
+    _ripple_trim_blanks_redo(self)
+     
+    # Reinit one roll trim
+    if self.first_do == True:
+        self.first_do = False
+        self.undo_done_callback(self.track, self.index + 1, False)
+
+#-------------------------------------------- RIPPLE TRIM START
+# "track","clip","index","edit_delta","first_do","multi_data"
+# self.multi_data is trimmodes.RippleData
+def ripple_trim_start_action(data):
+    action = EditAction(_ripple_trim_start_undo,_ripple_trim_start_redo, data)
+    action.exit_active_trimmode_on_edit = False
+    action.update_hidden_track_blank = False
+    return action
+
+def _ripple_trim_start_undo(self):
+    _remove_clip(self.track, self.index)
+    _insert_clip(self.track, self.clip, self.index,
+                 self.clip.clip_in - self.edit_delta, self.clip.clip_out)
+
+    _ripple_trim_blanks_undo(self, True)
+
+def _ripple_trim_start_redo(self):
+    _remove_clip(self.track, self.index)
+    _insert_clip(self.track, self.clip, self.index,
+                 self.clip.clip_in + self.edit_delta, self.clip.clip_out)
+
+    _ripple_trim_blanks_redo(self, True)
+    
+    # Reinit one roll trim, when used with clip start drag this is not needed
+    if  hasattr(self, "first_do") and self.first_do == True:
+        self.first_do = False
+        self.undo_done_callback(self.track, self.index, True)
+
+#------------------ RIPPLE TRIM LAST CLIP END
+# "track","clip","index","edit_delta","first_do","multi_data"
+# self.multi_data is trimmodes.RippleData
+def ripple_trim_last_clip_end_action(data): 
+    action = EditAction(_ripple_trim_last_clip_end_undo,_ripple_trim_last_clip_end_redo, data)
+    action.exit_active_trimmode_on_edit = False
+    action.update_hidden_track_blank = False
+    return action
+
+def _ripple_trim_last_clip_end_undo(self):
+    _remove_clip(self.track, self.index)
+    _insert_clip(self.track, self.clip, self.index,
+                 self.clip.clip_in, self.clip.clip_out - self.edit_delta)
+
+    _ripple_trim_blanks_undo(self)
+
+def _ripple_trim_last_clip_end_redo(self):
+    print self.__dict__
+    _remove_clip(self.track, self.index)
+    _insert_clip(self.track, self.clip, self.index,
+                 self.clip.clip_in, self.clip.clip_out + self.edit_delta)
+
+    _ripple_trim_blanks_redo(self)
+    
+    # Reinit one roll trim for continued trim mode, whenused with clip end drag this is not needed
+    if hasattr(self, "first_do") and self.first_do == True:
+        self.first_do = False
+        self.undo_done_callback(self.track)
+        
+# ----------------------------- RIPPLE TRIM BLANK UPDATE METHODS
+def _ripple_trim_blanks_undo(self, reverse_comp_delta=False):
+    track_moved = self.multi_data.track_affected    
+    tracks = current_sequence().tracks
+
+    applied_delta = self.edit_delta
+        
+    for i in range(1, len(tracks) - 1):
+        if not track_moved[i - 1]:
+            continue
+        if self.track.id == i:
+            continue
+
+        track = tracks[i]
+        edit_op = self.multi_data.track_edit_ops[i - 1]        
+        trim_blank_index = self.multi_data.trim_blank_indexes[i - 1]
+        
+        if edit_op == appconsts.MULTI_NOOP:
+            continue
+        elif edit_op == appconsts.MULTI_TRIM:
+            blank_length = track.clips[trim_blank_index].clip_length()
+            _remove_clip(track, trim_blank_index) 
+            _insert_blank(track, trim_blank_index, blank_length - applied_delta)
+        elif edit_op == appconsts.MULTI_ADD_TRIM:
+            _remove_clip(track, trim_blank_index) 
+        elif edit_op == appconsts.MULTI_TRIM_REMOVE:
+            #print "MULTI_TRIM_REMOVE for track", track.id, "values: ", self.edit_delta, applied_delta, -self.multi_data.max_backwards
+            if reverse_comp_delta:
+                if -self.edit_delta != -self.multi_data.max_backwards:
+                    _remove_clip(track, trim_blank_index) 
+            else:
+                if self.edit_delta != -self.multi_data.max_backwards:
+                    _remove_clip(track, trim_blank_index) 
+                
+            _insert_blank(track, trim_blank_index, self.orig_length)
+
+    if reverse_comp_delta:
+        applied_delta = -applied_delta
+    _ripple_trim_compositors_move(self, -applied_delta)
+
+def _ripple_trim_blanks_redo(self, reverse_delta=False):
+    tracks = current_sequence().tracks
+    track_moved = self.multi_data.track_affected
+    
+    applied_delta = self.edit_delta
+    if reverse_delta:
+        applied_delta = -applied_delta
+               
+    for i in range(1, len(tracks) - 1):
+        if not track_moved[i - 1]:
+            continue
+        if self.track.id == i:
+            continue
+            
+        track = tracks[i]
+        edit_op = self.multi_data.track_edit_ops[i - 1]        
+        trim_blank_index = self.multi_data.trim_blank_indexes[i - 1]
+        
+        if edit_op == appconsts.MULTI_NOOP: # no blank clip on this track is not changed
+            continue
+        elif edit_op == appconsts.MULTI_TRIM: #longer available blank than max_backwards, lenth is changed
+            blank_length = track.clips[trim_blank_index].clip_length()
+            _remove_clip(track, trim_blank_index) 
+            _insert_blank(track, trim_blank_index, blank_length + applied_delta)
+        elif edit_op == appconsts.MULTI_ADD_TRIM:# no blank to trim available, only possibnle edit is to add blank
+            _insert_blank(track, trim_blank_index, applied_delta)
+        elif edit_op == appconsts.MULTI_TRIM_REMOVE: # blank is trimmed if not max length triom, if so, blank is removed
+            self.orig_length = track.clips[trim_blank_index].clip_length()
+            _remove_clip(track, trim_blank_index)
+            #print "MULTI_TRIM_REMOVE for track", track.id, "values: ", applied_delta, -self.multi_data.max_backwards
+            if applied_delta != -self.multi_data.max_backwards:
+                _insert_blank(track, trim_blank_index, self.orig_length + applied_delta)
+
+    _ripple_trim_compositors_move(self, applied_delta)
+
+def _ripple_trim_compositors_move(self, delta):
+    comp_ids = self.multi_data.moved_compositors_destroy_ids
+    tracks_compositors = _get_tracks_compositors_list()
+    track_moved = self.multi_data.track_affected
+
+    for i in range(1, len(current_sequence().tracks) - 1):
+        if not track_moved[i - 1]:
+            continue
+        track_comps = tracks_compositors[i - 1]
+        for comp in track_comps:
+            if comp.destroy_id in comp_ids:
+                comp.move(delta)
+
+
 #------------------ TRIM CLIP START
 # "track","clip","index","delta","first_do"
 # "undo_done_callback" <- THIS IS REALLY BADLY NAMED, IT SHOULD BE FIRST DO CALLBACK
@@ -1189,7 +1420,7 @@ def _trim_last_clip_end_redo(self):
     _insert_clip(self.track, self.clip, self.index,
                  self.clip.clip_in, self.clip.clip_out + self.delta)
 
-    # Reinit one roll trim for continued trim mode, whenused with clip end drag this is not needed
+    # Reinit one roll trim for continued trim mode
     if hasattr(self, "first_do") and self.first_do == True:
         self.first_do = False
         self.undo_done_callback(self.track)
@@ -2217,7 +2448,6 @@ def _append_media_log_redo(self):
 
 
 # --------------------------------------------- help funcs for "range over" and "range splice out" edits
-# NOTE: RANGE SPLICE OUT NOT IMPLEMENTED YET; SO THIS IS CURRENTLY DEAD CODE
 def _track_put_back_range(over_in, track, track_extract_data):
     # get index for first clip that was removed
     moved_index = track.get_clip_index_at(over_in)
@@ -2260,8 +2490,6 @@ def _track_put_back_range(over_in, track, track_extract_data):
                      
     #_remove_trailing_blanks(track)
 
-# NOTE: RANGE SPLICE OUT NOT IMPLEMENTED YET; SO THIS IS BASICALLY UNNECESSARY METHOD CAUSING 
-# CODE DUPLICATION WITH OTHER OVERWRITE METHODS
 def _track_extract_range(over_in, over_out, track):
     track_extract_data = utils.EmptyClass()
 
