@@ -170,15 +170,19 @@ def get_recent_projects():
 
 def update_prefs_from_widgets(widgets_tuples_tuple):
     # Unpack widgets
-    gen_opts_widgets, edit_prefs_widgets, view_prefs_widgets = widgets_tuples_tuple
+    gen_opts_widgets, edit_prefs_widgets, view_prefs_widgets, performance_widgets = widgets_tuples_tuple
 
     default_profile_combo, open_in_last_opened_check, open_in_last_rendered_check, undo_max_spin, load_order_combo = gen_opts_widgets
     
     # Jul-2016 - SvdB - Added play_pause_button
     auto_play_in_clip_monitor_check, auto_center_check, grfx_insert_length_spin, \
-    trim_exit_click, trim_quick_enter, remember_clip_frame, overwrite_clip_drop, cover_delete, play_pause_button = edit_prefs_widgets
+        trim_exit_click, trim_quick_enter, remember_clip_frame, overwrite_clip_drop, cover_delete, \
+        play_pause_button, mouse_scroll_action, hide_file_ext_button, auto_center_on_updown = edit_prefs_widgets
     
-    use_english, disp_splash, buttons_style, dark_theme, theme_combo, audio_levels_combo, window_mode_combo = view_prefs_widgets
+    use_english, disp_splash, buttons_style, dark_theme, theme_combo, audio_levels_combo, window_mode_combo, full_names = view_prefs_widgets
+
+    # Jan-2017 - SvdB
+    perf_render_threads, perf_drop_frames = performance_widgets
 
     global prefs
     prefs.open_in_last_opended_media_dir = open_in_last_opened_check.get_active()
@@ -197,6 +201,8 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.trans_cover_delete = cover_delete.get_active()
     # Jul-2016 - SvdB - For play/pause button
     prefs.play_pause = play_pause_button.get_active()
+    prefs.hide_file_ext = hide_file_ext_button.get_active()
+    prefs.mouse_scroll_action_is_zoom = (mouse_scroll_action.get_active() == 0)
     
     prefs.use_english_always = use_english.get_active()
     prefs.display_splash_screen = disp_splash.get_active()
@@ -205,6 +211,12 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.theme_fallback_colors = theme_combo.get_active() 
     prefs.display_all_audio_levels = (audio_levels_combo.get_active() == 0)
     prefs.global_layout = window_mode_combo.get_active() + 1 # +1 'cause values are 1 and 2
+    # Jan-2017 - SvdB
+    prefs.perf_render_threads = int(perf_render_threads.get_adjustment().get_value())
+    prefs.perf_drop_frames = perf_drop_frames.get_active()
+    # Feb-2017 - SvdB - for full file names
+    prefs.show_full_file_names = full_names.get_active()
+    prefs.center_on_arrow_move = auto_center_on_updown.get_active()
 
 def get_graphics_default_in_out_length():
     in_fr = int(15000/2) - int(prefs.default_grfx_length/2)
@@ -232,6 +244,9 @@ class EditorPreferences:
     """
 
     def __init__(self):
+        
+        # Every preference needs to have its default value set in this constructor
+        
         self.open_in_last_opended_media_dir = True
         self.last_opened_media_dir = None
         self.img_length = 2000
@@ -245,7 +260,7 @@ class EditorPreferences:
         self.display_splash_screen = True
         self.auto_move_after_edit = False
         self.default_grfx_length = 250 # value is in frames
-        self.track_configuration = 0 # this is index on list appconsts.TRACK_CONFIGURATIONS
+        self.track_configuration = 0 # DEPRECATED
         self.AUTO_SAVE_OPTS = None # not used, these are cerated and translated else where
         self.tabs_on_top = False
         self.midbar_tc_left = True
@@ -280,5 +295,11 @@ class EditorPreferences:
         self.trim_view_default = appconsts.TRIM_VIEW_OFF
         self.trim_view_message_shown = False
         self.exit_allocation_window_2 = (0, 0, 0, 0)
-        
-        
+        self.mouse_scroll_action_is_zoom = True
+        self.hide_file_ext = False
+        # Jan-2017 - SvdB
+        self.perf_render_threads = 1
+        self.perf_drop_frames = False
+        # Feb-2017 - SvdB - for full file names
+        self.show_full_file_names = False
+        self.center_on_arrow_move = False
