@@ -32,6 +32,7 @@ import app
 import appconsts
 import audiomonitoring
 import batchrendering
+import boxmove
 import clipeffectseditor
 import clipmenuaction
 import compositeeditor
@@ -79,6 +80,7 @@ DARK_BG_COLOR = (0.223, 0.247, 0.247, 1.0)
 
 # Cursors
 OVERWRITE_CURSOR = None
+OVERWRITE_BOX_CURSOR = None
 INSERTMOVE_CURSOR = None
 ONEROLL_CURSOR = None
 ONEROLL_NO_EDIT_CURSOR = None
@@ -87,7 +89,10 @@ TWOROLL_NO_EDIT_CURSOR = None
 SLIDE_CURSOR = None
 SLIDE_NO_EDIT_CURSOR = None
 MULTIMOVE_CURSOR = None
+ONEROLL_RIPPLE_CURSOR = None
 
+ONEROLL_TOOL = None
+OVERWRITE_TOOL = None
 
 def _b(button, icon, remove_relief=False):
     button.set_image(icon)
@@ -112,9 +117,12 @@ class EditorWindow:
         # Read cursors
         global INSERTMOVE_CURSOR, OVERWRITE_CURSOR, TWOROLL_CURSOR, ONEROLL_CURSOR, \
         ONEROLL_NO_EDIT_CURSOR, TWOROLL_NO_EDIT_CURSOR, SLIDE_CURSOR, SLIDE_NO_EDIT_CURSOR, \
-        MULTIMOVE_CURSOR, MULTIMOVE_NO_EDIT_CURSOR
+        MULTIMOVE_CURSOR, MULTIMOVE_NO_EDIT_CURSOR, ONEROLL_RIPPLE_CURSOR, ONEROLL_TOOL, \
+        OVERWRITE_BOX_CURSOR, OVERWRITE_TOOL
+        
         INSERTMOVE_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "insertmove_cursor.png")
         OVERWRITE_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "overwrite_cursor.png")
+        OVERWRITE_BOX_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "overwrite_cursor_box.png")
         TWOROLL_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "tworoll_cursor.png")
         ONEROLL_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "oneroll_cursor.png")
         SLIDE_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "slide_cursor.png")
@@ -123,6 +131,9 @@ class EditorWindow:
         SLIDE_NO_EDIT_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "slide_noedit_cursor.png")
         MULTIMOVE_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "multimove_cursor.png")
         MULTIMOVE_NO_EDIT_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "multimove_cursor.png")
+        ONEROLL_RIPPLE_CURSOR = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "oneroll_cursor_ripple.png")
+        ONEROLL_TOOL = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "oneroll_tool.png")
+        OVERWRITE_TOOL =  cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "overwrite_tool.png")
 
         # Window
         self.window = Gtk.Window(Gtk.WindowType.TOPLEVEL)
@@ -222,7 +233,8 @@ class EditorWindow:
             ('OneRollMode', None, None, '3', None, lambda a:_this_is_not_used()),
             ('TwoRollMode', None, None, '4', None, lambda a:_this_is_not_used()),
             ('SlideMode', None, None, '5', None, lambda a:_this_is_not_used()),
-            ('MultiMode', None, None, '6', None, lambda a:_this_is_not_used())
+            ('MultiMode', None, None, '6', None, lambda a:_this_is_not_used()),
+            ('BoxMode', None, None, '7', None, lambda a:_this_is_not_used())
             ]
 
         menu_string = """<ui>
@@ -938,7 +950,7 @@ class EditorWindow:
         self.pos_bar.set_listener(mltplayer.seek_position_normalized)
 
     def _get_edit_buttons_row(self):
-        modes_pixbufs = [INSERTMOVE_CURSOR, OVERWRITE_CURSOR, ONEROLL_CURSOR, TWOROLL_CURSOR, SLIDE_CURSOR, MULTIMOVE_CURSOR]
+        modes_pixbufs = [INSERTMOVE_CURSOR, OVERWRITE_CURSOR, ONEROLL_CURSOR, ONEROLL_RIPPLE_CURSOR, TWOROLL_CURSOR, SLIDE_CURSOR, MULTIMOVE_CURSOR, OVERWRITE_BOX_CURSOR]
         middlebar.create_edit_buttons_row_buttons(self, modes_pixbufs)
     
         buttons_row = Gtk.HBox(False, 1)
@@ -972,6 +984,10 @@ class EditorWindow:
         editevent.overwrite_move_mode_pressed()
         self.set_cursor_to_mode()
 
+    def handle_box_mode_button_press(self):
+        editevent.box_mode_pressed()
+        self.set_cursor_to_mode()
+
     def handle_insert_move_mode_button_press(self):
         editevent.insert_move_mode_pressed()
         self.set_cursor_to_mode()
@@ -992,6 +1008,21 @@ class EditorWindow:
         editevent.multi_mode_pressed()
         self.set_cursor_to_mode()
 
+    def toggle_trim_ripple_mode(self):
+        editorstate.trim_mode_ripple = (editorstate.trim_mode_ripple == False)
+        editevent.stop_looping()
+        editorstate.edit_mode = editorstate.ONE_ROLL_TRIM_NO_EDIT
+        tlinewidgets.set_edit_mode(None, None)
+        self.set_mode_selector_to_mode()
+        self.set_tline_cursor(editorstate.EDIT_MODE())
+        updater.set_trim_mode_gui()
+    
+    def toggle_overwrite_box_mode(self):
+        editorstate.overwrite_mode_box = (editorstate.overwrite_mode_box == False)
+        boxmove.clear_data()
+        self.set_mode_selector_to_mode()
+        self.set_tline_cursor(editorstate.EDIT_MODE())
+        
     def mode_selector_pressed(self, selector, event):
         guicomponents.get_mode_selector_popup_menu(selector, event, self.mode_selector_item_activated)
     
@@ -1001,14 +1032,19 @@ class EditorWindow:
         if mode == 1:
             self.handle_over_move_mode_button_press()
         if mode == 2:
-            self.handle_one_roll_mode_button_press()
+            if editorstate.edit_mode != editorstate.ONE_ROLL_TRIM and editorstate.edit_mode != editorstate.ONE_ROLL_TRIM_NO_EDIT:
+                self.handle_one_roll_mode_button_press()
+            else:
+                self.toggle_trim_ripple_mode()
         if mode == 3:
             self.handle_two_roll_mode_button_press()
         if mode == 4:
             self.handle_slide_mode_button_press()
         if mode == 5:
             self.handle_multi_mode_button_press()
-        
+        if mode == 6:
+            self.handle_box_mode_button_press()
+                
         self.set_cursor_to_mode()
         self.set_mode_selector_to_mode()
         
@@ -1025,20 +1061,29 @@ class EditorWindow:
 
     def set_tline_cursor(self, mode):
         display = Gdk.Display.get_default()
-        gdk_window = self.window.get_window()#gui.tline_display.get_window()
+        gdk_window = self.window.get_window()
 
         if mode == editorstate.INSERT_MOVE:
             cursor = self.get_own_cursor(display, INSERTMOVE_CURSOR, 0, 0)
         elif mode == editorstate.OVERWRITE_MOVE:
-            cursor = self.get_own_cursor(display, OVERWRITE_CURSOR, 6, 15)
+            if editorstate.overwrite_mode_box == False:
+                cursor = self.get_own_cursor(display, OVERWRITE_CURSOR, 6, 15)
+            else:
+                cursor = self.get_own_cursor(display, OVERWRITE_BOX_CURSOR, 6, 15)
         elif mode == editorstate.TWO_ROLL_TRIM:
             cursor = self.get_own_cursor(display, TWOROLL_CURSOR, 11, 9)
         elif mode == editorstate.TWO_ROLL_TRIM_NO_EDIT:
             cursor = self.get_own_cursor(display, TWOROLL_NO_EDIT_CURSOR, 11, 9)
         elif mode == editorstate.ONE_ROLL_TRIM:
-            cursor = self.get_own_cursor(display, ONEROLL_CURSOR, 9, 9)
+            if editorstate.trim_mode_ripple == False:
+                cursor = self.get_own_cursor(display, ONEROLL_CURSOR, 9, 9)
+            else:
+                cursor = self.get_own_cursor(display, ONEROLL_RIPPLE_CURSOR, 9, 9)
         elif mode == editorstate.ONE_ROLL_TRIM_NO_EDIT:
-            cursor = self.get_own_cursor(display, ONEROLL_NO_EDIT_CURSOR, 9, 9)
+            if editorstate.trim_mode_ripple == False:
+                cursor = self.get_own_cursor(display, ONEROLL_NO_EDIT_CURSOR, 9, 9)
+            else:
+                cursor = self.get_own_cursor(display, ONEROLL_RIPPLE_CURSOR, 9, 9)
         elif mode == editorstate.SLIDE_TRIM:
             cursor = self.get_own_cursor(display, SLIDE_CURSOR, 9, 9)
         elif mode == editorstate.SLIDE_TRIM_NO_EDIT:
@@ -1058,21 +1103,25 @@ class EditorWindow:
         if editorstate.EDIT_MODE() == editorstate.INSERT_MOVE:
             self.modes_selector.set_pixbuf(0)
         elif editorstate.EDIT_MODE() == editorstate.OVERWRITE_MOVE:
-            self.modes_selector.set_pixbuf(1)
-        elif editorstate.EDIT_MODE() == editorstate.ONE_ROLL_TRIM:
-            self.modes_selector.set_pixbuf(2)
-        elif editorstate.EDIT_MODE() == editorstate.ONE_ROLL_TRIM_NO_EDIT:
-            self.modes_selector.set_pixbuf(2)
+            if editorstate.overwrite_mode_box == False:
+                self.modes_selector.set_pixbuf(1)
+            else:
+                self.modes_selector.set_pixbuf(7)
+        elif editorstate.EDIT_MODE() == editorstate.ONE_ROLL_TRIM or editorstate.EDIT_MODE() == editorstate.ONE_ROLL_TRIM_NO_EDIT:
+            if editorstate.trim_mode_ripple == False:
+                self.modes_selector.set_pixbuf(2)
+            else:
+                self.modes_selector.set_pixbuf(3)
         elif editorstate.EDIT_MODE() == editorstate.TWO_ROLL_TRIM:
-            self.modes_selector.set_pixbuf(3)
+            self.modes_selector.set_pixbuf(4)
         elif editorstate.EDIT_MODE() == editorstate.TWO_ROLL_TRIM_NO_EDIT:
-            self.modes_selector.set_pixbuf(3)
+            self.modes_selector.set_pixbuf(4)
         elif editorstate.EDIT_MODE() == editorstate.SLIDE_TRIM:
-            self.modes_selector.set_pixbuf(4)
-        elif editorstate.EDIT_MODE() == editorstate.SLIDE_TRIM_NO_EDIT:
-            self.modes_selector.set_pixbuf(4)
-        elif editorstate.EDIT_MODE() == editorstate.MULTI_MOVE:
             self.modes_selector.set_pixbuf(5)
+        elif editorstate.EDIT_MODE() == editorstate.SLIDE_TRIM_NO_EDIT:
+            self.modes_selector.set_pixbuf(5)
+        elif editorstate.EDIT_MODE() == editorstate.MULTI_MOVE:
+            self.modes_selector.set_pixbuf(6)
 
     def tline_cursor_leave(self, event):
         cursor = Gdk.Cursor.new(Gdk.CursorType.LEFT_PTR)
