@@ -926,8 +926,14 @@ class MediaObjectWidget:
 
         txt = Gtk.Label(label=media_file.name)
         txt.modify_font(Pango.FontDescription("sans 9"))
-        txt.set_ellipsize(Pango.EllipsizeMode.END)
         txt.set_max_width_chars(13)
+        # Feb-2017 - SvdB - For full file names. First part shows the original code for short file names        
+        if editorpersistance.prefs.show_full_file_names == False:
+            txt.set_ellipsize(Pango.EllipsizeMode.END)
+        else:
+            txt.set_line_wrap_mode(Pango.WrapMode.CHAR)
+            txt.set_line_wrap(True)
+        # end SvdB
         txt.set_tooltip_text(media_file.name)
 
         self.vbox.pack_start(self.img, True, True, 0)
@@ -1801,8 +1807,11 @@ class BigTCDisplay:
         cr.stroke()
 
         # Get current TIMELINE frame str
-        frame = PLAYER().tracktor_producer.frame()
-        frame_str = utils.get_tc_string(frame)
+        try:
+            frame = PLAYER().tracktor_producer.frame()
+            frame_str = utils.get_tc_string(frame)
+        except:
+            frame_str = "00:00:00:00"
 
         # Text
         layout = PangoCairo.create_layout(cr)
@@ -1945,6 +1954,54 @@ class TimeLineLeftBottom:
         self.widget.queue_draw()
 
 
+class TracksNumbersSelect:
+    def __init__(self, v_tracks, a_tracks):
+        
+        self.MAX_TRACKS = appconsts.MAX_TRACKS
+        
+        self.widget = Gtk.HBox()
+        self.video_label = Gtk.Label(_("Video:"))
+        self.video_tracks = Gtk.SpinButton.new_with_range(1, 8, 1)
+        self.video_tracks.set_value(v_tracks)
+        #self.video_tracks.set_editable(False)
+        self.video_tracks.connect("value-changed", self.video_tracks_changed)
+        self.audio_label = Gtk.Label(_("Audio:"))
+        self.audio_tracks = Gtk.SpinButton.new_with_range(1, 8, 1)
+        self.audio_tracks.set_value(a_tracks)
+        #self.audio_tracks.set_editable(False)
+        self.audio_tracks.connect("value-changed", self.audio_tracks_changed)
+        self.label = Gtk.Label(_("Number of Tracks:"))
+        self.tracks_amount_info = Gtk.Label()
+        self.set_total_tracks_info()
+
+        self.widget.pack_start(self.label, False, False, 0)
+        self.widget.pack_start(guiutils.pad_label(22,2), False, False, 0)
+        self.widget.pack_start(self.video_label, False, False, 0)
+        self.widget.pack_start(self.video_tracks, False, False, 0)
+        self.widget.pack_start(guiutils.pad_label(22,2), False, False, 0)
+        self.widget.pack_start(self.audio_label, False, False, 0)
+        self.widget.pack_start(self.audio_tracks, False, False, 0)
+        self.widget.pack_start(guiutils.pad_label(22,2), False, False, 0)
+        self.widget.pack_start(self.tracks_amount_info, False, False, 0)
+        self.widget.pack_start(Gtk.Label(), True, True, 0)
+
+    def video_tracks_changed(self, adjustment):
+        if self.video_tracks.get_value() + self.audio_tracks.get_value() > self.MAX_TRACKS:
+            self.audio_tracks.set_value(self.MAX_TRACKS - self.video_tracks.get_value())
+        self.set_total_tracks_info()
+
+    def audio_tracks_changed(self, adjustment):
+        if self.video_tracks.get_value() + self.audio_tracks.get_value() > self.MAX_TRACKS:
+            self.video_tracks.set_value(self.MAX_TRACKS - self.audio_tracks.get_value())
+        self.set_total_tracks_info()
+        
+    def set_total_tracks_info(self):
+        self.tracks_amount_info.set_text(str(int(self.video_tracks.get_value() + self.audio_tracks.get_value())) + " / 9")
+        self.tracks_amount_info.queue_draw ()
+
+    def get_tracks(self):
+        return (int(self.video_tracks.get_value()), int(self.audio_tracks.get_value()))
+
 def get_gpl3_scroll_widget(size):
     license_file = open(respaths.GPL_3_DOC)
     license_text = license_file.read()
@@ -1967,12 +2024,15 @@ def get_translations_scroll_widget(size):
     trans_file = open(respaths.TRANSLATIONS_DOC)
     trans_text = trans_file.read()
 
+    return get_text_scroll_widget(trans_text, size)
+    
+def get_text_scroll_widget(text, size):
     view = Gtk.TextView()
     view.set_editable(False)
     view.set_pixels_above_lines(2)
     view.set_left_margin(2)
     view.set_wrap_mode(Gtk.WrapMode.WORD)
-    view.get_buffer().set_text(trans_text)
+    view.get_buffer().set_text(text)
 
     sw = Gtk.ScrolledWindow()
     sw.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
@@ -1981,20 +2041,6 @@ def get_translations_scroll_widget(size):
 
     return sw
 
-def get_track_counts_combo_and_values_list():
-    tracks_combo = Gtk.ComboBoxText()
-    tracks_combo.append_text(_("5 video, 4 audio"))
-    tracks_combo.append_text(_("4 video, 3 audio"))
-    tracks_combo.append_text(_("3 video, 2 audio"))
-    tracks_combo.append_text(_("2 video, 1 audio"))
-    tracks_combo.append_text(_("7 video, 2 audio"))
-    tracks_combo.append_text(_("2 video, 7 audio"))
-    tracks_combo.append_text(_("8 video, 1 audio"))
-    tracks_combo.append_text(_("1 video, 8 audio"))
-    tracks_combo.set_active(0)
-    tracks_combo_values_list = appconsts.TRACK_CONFIGURATIONS
-    return (tracks_combo, tracks_combo_values_list)
-
 def get_markers_menu_launcher(callback, pixbuf):
     m_launch = PressLaunch(callback, pixbuf)
     return m_launch
@@ -2223,6 +2269,12 @@ def get_mode_selector_popup_menu(launcher, event, callback):
     menu.add(menu_item)
     menu_items.append(menu_item)
 
+    menu_item = _get_image_menu_item(Gtk.Image.new_from_file(
+        respaths.IMAGE_PATH + "overwrite_cursor_box.png"), _("Box"), callback, 6)
+    menu_item.set_accel_path("<Actions>/WindowActions/BoxMode")
+    menu.add(menu_item)
+    menu_items.append(menu_item)
+    
     menu.connect("hide", lambda w : _tools_menu_hidden(w,menu_items))
     menu.show_all()
     menu.popup(None, None, None, None, event.button, event.time)
