@@ -32,6 +32,7 @@ import compositormodes
 import glassbuttons
 import gui
 import editevent
+import editorpersistance
 import editorstate
 from editorstate import current_sequence
 from editorstate import PLAYER
@@ -120,6 +121,14 @@ def key_down(widget, event):
         _move_to_beginning()
         return True
 
+    # End
+    if event.keyval == Gdk.KEY_End:
+        if PLAYER().is_playing():
+            monitorevent.stop_pressed()
+        PLAYER().seek_end()
+        _move_to_end()
+        return True
+
     # Select all with CTRL + A in media panel
     if event.keyval == Gdk.KEY_a:
         if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
@@ -228,6 +237,10 @@ def _handle_tline_key_event(event):
         gui.editor_window.handle_multi_mode_button_press()
         gui.editor_window.set_mode_selector_to_mode()
         return True
+    if event.keyval == Gdk.KEY_7:
+        gui.editor_window.handle_box_mode_button_press()
+        gui.editor_window.set_mode_selector_to_mode()
+        return True
         
     # X
     if event.keyval == Gdk.KEY_x:
@@ -239,6 +252,10 @@ def _handle_tline_key_event(event):
         medialog.log_range_clicked()
         return True
 
+    # R
+    if event.keyval == Gdk.KEY_r:
+        gui.editor_window.toggle_trim_ripple_mode()
+        return True
 
     # Key bindings for keyboard trimming
     if editorstate.current_is_active_trim_mode() == True:
@@ -265,6 +282,8 @@ def _handle_tline_key_event(event):
                 frame = current_sequence().find_next_cut_frame(tline_frame)
                 if frame != -1:
                     PLAYER().seek_frame(frame)
+                    if editorpersistance.prefs.center_on_arrow_move == True:
+                        updater.center_tline_to_current_frame()
                     return True
             else:
                 monitorevent.up_arrow_seek_on_monitor_clip()
@@ -276,6 +295,8 @@ def _handle_tline_key_event(event):
                 frame = current_sequence().find_prev_cut_frame(tline_frame)
                 if frame != -1:
                     PLAYER().seek_frame(frame)
+                    if editorpersistance.prefs.center_on_arrow_move == True:
+                        updater.center_tline_to_current_frame()
                     return True
             else:
                  monitorevent.down_arrow_seek_on_monitor_clip()
@@ -331,8 +352,8 @@ def _handle_tline_key_event(event):
                 monitorevent.l_pressed()
             return True
 
-        # R
-        if event.keyval == Gdk.KEY_r:
+        # S
+        if event.keyval == Gdk.KEY_s:
             tlineaction.resync_button_pressed()
             return True
             
@@ -350,6 +371,14 @@ def _handle_tline_key_event(event):
             PLAYER().seek_frame(0)
             _move_to_beginning()
             return True
+
+        # END
+        if event.keyval == Gdk.KEY_End:
+            if PLAYER().is_playing():
+                monitorevent.stop_pressed()
+            PLAYER().seek_end()
+            _move_to_end()
+            return True
     else:
         # HOME
         if event.keyval == Gdk.KEY_Home:
@@ -361,6 +390,16 @@ def _handle_tline_key_event(event):
             _move_to_beginning()
             return True
 
+        # END
+        if event.keyval == Gdk.KEY_End:
+            if PLAYER().is_playing():
+                monitorevent.stop_pressed()
+            gui.editor_window.handle_insert_move_mode_button_press()
+            gui.editor_window.set_mode_selector_to_mode()
+            PLAYER().seek_end()
+            _move_to_end()
+            return True
+
     return False
 
 
@@ -441,6 +480,10 @@ def _handle_extended_tline_focus_events(event):
         gui.editor_window.handle_multi_mode_button_press()
         gui.editor_window.set_mode_selector_to_mode()
         return True
+    if event.keyval == Gdk.KEY_7:
+        gui.editor_window.handle_box_mode_button_press()
+        gui.editor_window.set_mode_selector_to_mode()
+        return True
 
     return False
         
@@ -470,6 +513,8 @@ def _handle_clip_key_event(event):
                 frame = current_sequence().find_next_cut_frame(tline_frame)
                 if frame != -1:
                     PLAYER().seek_frame(frame)
+                    if editorpersistance.prefs.center_on_arrow_move == True:
+                        updater.center_tline_to_current_frame()
                     return True
             else:
                  monitorevent.up_arrow_seek_on_monitor_clip()
@@ -482,6 +527,8 @@ def _handle_clip_key_event(event):
                 frame = current_sequence().find_prev_cut_frame(tline_frame)
                 if frame != -1:
                     PLAYER().seek_frame(frame)
+                    if editorpersistance.prefs.center_on_arrow_move == True:
+                        updater.center_tline_to_current_frame()  
                     return True
             else:
                  monitorevent.down_arrow_seek_on_monitor_clip()
@@ -574,7 +621,7 @@ def _handle_geometry_editor_keys(event):
                         or (event.keyval == Gdk.KEY_Right)
                         or (event.keyval == Gdk.KEY_Up)
                         or (event.keyval == Gdk.KEY_Down)):
-                        kfeditor.arrow_edit(event.keyval)
+                        kfeditor.arrow_edit(event.keyval, (event.get_state() & Gdk.ModifierType.CONTROL_MASK))
                         return True
                     if event.keyval == Gdk.KEY_plus:
                         pass # not impl
@@ -611,5 +658,7 @@ def _move_to_beginning():
     updater.repaint_tline()
     updater.update_tline_scrollbar()
     
-    
-    
+def _move_to_end():
+    updater.repaint_tline()
+    updater.update_tline_scrollbar()
+
