@@ -883,12 +883,14 @@ class AbstractScreenEditor:
                 delta_x = 0
             else:
                 delta_y = 0
-        
-        self._shape__motion_notify_event(delta_x, delta_y)
+        #elif state & Gdk.ModifierType.CONTROL_MASK:
+        #    print "control"
+                
+        self._shape__motion_notify_event(delta_x, delta_y, (state & Gdk.ModifierType.CONTROL_MASK))
 
         self.parent_editor.queue_draw()
     
-    def _shape__motion_notify_event(self, delta_x, delta_y):
+    def _shape__motion_notify_event(self, delta_x, delta_y, CTRL_DOWN):
         print "_shape__motion_notify_event not impl"
 
     
@@ -905,11 +907,11 @@ class AbstractScreenEditor:
             else:
                 delta_y = 0
                 
-        self._shape_release_event(delta_x, delta_y)
+        self._shape_release_event(delta_x, delta_y, (event.get_state() & Gdk.ModifierType.CONTROL_MASK))
             
         self.parent_editor.geometry_edit_finished()
 
-    def _shape_release_event(self, delta_x, delta_y):
+    def _shape_release_event(self, delta_x, delta_y, CTRL_DOWN):
         print "_shape_release_event not impl"
 
     def _mouse_scroll_listener(self, event):
@@ -1089,28 +1091,28 @@ class BoxGeometryScreenEditor(AbstractScreenEditor):
         else:
             self.source_edit_rect.edit_point_drag_started(self.current_mouse_hit)
 
-    def _shape__motion_notify_event(self, delta_x, delta_y):
+    def _shape__motion_notify_event(self, delta_x, delta_y, CTRL_DOWN):
         if self.current_mouse_hit == AREA_HIT:
             self.source_edit_rect.move_drag(delta_x, delta_y)
         else:
             self.source_edit_rect.edit_point_drag(delta_x, delta_y)
 
-    def _shape_release_event(self, delta_x, delta_y):
+    def _shape_release_event(self, delta_x, delta_y, CTRL_DOWN):
         if self.current_mouse_hit == AREA_HIT:
             self.source_edit_rect.move_drag(delta_x, delta_y)
         else:
             self.source_edit_rect.edit_point_drag(delta_x, delta_y)
             self.source_edit_rect.clear_projection_point()
 
-    def handle_arrow_edit(self, keyval):
+    def handle_arrow_edit(self, keyval, delta):
         if keyval == Gdk.KEY_Left:
-            self.source_edit_rect.x -= 1
+            self.source_edit_rect.x -= delta
         if keyval == Gdk.KEY_Right:
-            self.source_edit_rect.x += 1
+            self.source_edit_rect.x += delta
         if keyval == Gdk.KEY_Up:
-            self.source_edit_rect.y -= 1
+            self.source_edit_rect.y -= delta
         if keyval == Gdk.KEY_Down:                         
-            self.source_edit_rect.y += 1
+            self.source_edit_rect.y += delta
             
     def print_keyframes(self):
         for i in range(0, len(self.keyframes)):
@@ -1257,15 +1259,15 @@ class RotatingScreenEditor(AbstractScreenEditor):
         r = r1 + (r2 - r1) * fract
         return (x, y, xs, ys, r)
 
-    def handle_arrow_edit(self, keyval):
+    def handle_arrow_edit(self, keyval, delta):
         if keyval == Gdk.KEY_Left:
-            self.shape_x -= 1
+            self.shape_x -= delta
         if keyval == Gdk.KEY_Right:
-            self.shape_x += 1
+            self.shape_x += delta
         if keyval == Gdk.KEY_Up:
-            self.shape_y -= 1
+            self.shape_y -= delta
         if keyval == Gdk.KEY_Down:                         
-            self.shape_y += 1
+            self.shape_y += delta
             
     # --------------------------------------------------------- mouse events
     def _shape_press_event(self):
@@ -1286,13 +1288,13 @@ class RotatingScreenEditor(AbstractScreenEditor):
             self.start_shape_x = self.shape_x 
             self.start_shape_y = self.shape_y
             
-    def _shape__motion_notify_event(self, delta_x, delta_y):
-        self._update_values_for_mouse_delta(delta_x, delta_y)
+    def _shape__motion_notify_event(self, delta_x, delta_y, CTRL_DOWN):
+        self._update_values_for_mouse_delta(delta_x, delta_y, CTRL_DOWN)
 
-    def _shape_release_event(self, delta_x, delta_y):
-        self._update_values_for_mouse_delta(delta_x, delta_y)
+    def _shape_release_event(self, delta_x, delta_y, CTRL_DOWN):
+        self._update_values_for_mouse_delta(delta_x, delta_y, CTRL_DOWN)
     
-    def _update_values_for_mouse_delta(self, delta_x, delta_y):
+    def _update_values_for_mouse_delta(self, delta_x, delta_y, CTRL_DOWN):
         if self.current_mouse_hit == POS_HANDLE or self.current_mouse_hit == AREA_HIT:
             dx = self.get_screen_x(self.coords.orig_x + delta_x)
             dy = self.get_screen_y(self.coords.orig_y + delta_y)
@@ -1305,6 +1307,8 @@ class RotatingScreenEditor(AbstractScreenEditor):
             dist = viewgeom.distance(self.edit_points[POS_HANDLE], pp)
             orig_dist = viewgeom.distance(self.untrans_points[POS_HANDLE], self.untrans_points[X_SCALE_HANDLE])
             self.x_scale = dist / orig_dist
+            if CTRL_DOWN:
+                self.y_scale = self.x_scale
             self._update_edit_points()
         elif self.current_mouse_hit == Y_SCALE_HANDLE:
             dp = self.get_delta_point(delta_x, delta_y, self.edit_points[Y_SCALE_HANDLE])
@@ -1312,6 +1316,8 @@ class RotatingScreenEditor(AbstractScreenEditor):
             dist = viewgeom.distance(self.edit_points[POS_HANDLE], pp)
             orig_dist = viewgeom.distance(self.untrans_points[POS_HANDLE], self.untrans_points[Y_SCALE_HANDLE])
             self.y_scale = dist / orig_dist
+            if CTRL_DOWN:
+                self.x_scale = self.y_scale
             self._update_edit_points()
         elif self.current_mouse_hit == ROTATION_HANDLE:
             ax, ay = self.edit_points[POS_HANDLE]
@@ -1882,8 +1888,12 @@ class GeometryEditor(AbstractKeyFrameEditor):
         self.update_property_value()
         self.buttons_row.set_kf_info(self.clip_editor.get_kf_info())
 
-    def arrow_edit(self, keyval):
-        self.geom_kf_edit.handle_arrow_edit(keyval)
+    def arrow_edit(self, keyval, CTRL_DOWN):
+        if CTRL_DOWN:
+            delta = 10
+        else:
+            delta = 1
+        self.geom_kf_edit.handle_arrow_edit(keyval, delta)
         self.geom_kf_edit.set_keyframe_to_edit_shape(self.clip_editor.active_kf_index)
         self.update_editor_view_with_frame(self.clip_editor.current_clip_frame)
         self.update_property_value()
