@@ -243,6 +243,7 @@ class CompositorTransition:
 
     def _set_affine_service_default_values(self):
         self.mlt_transition.set("distort",0)
+        #self.mlt_transition.set("fill",0)
         self.mlt_transition.set("automatic",1)
         self.mlt_transition.set("keyed",1)
    
@@ -308,7 +309,7 @@ class CompositorObject:
         self.origin_clip_id = None
         
         self.destroy_id = os.urandom(16) # HACK, HACK, HACK - find a way to remove this stuff  
-                                         # Objects are recreated often in Sequence.restack_compositors()
+                                         # Compositors are recreated often in Sequence.restack_compositors()
                                          # and cannot be destroyd in undo/redo with object identidy.
                                          # This is cloned in clone_properties
 
@@ -337,6 +338,20 @@ class CompositorObject:
         self.transition.properties = copy.deepcopy(source_compositor.transition.properties)
         self.transition.update_editable_mlt_properties()
 
+    def get_copy_paste_objects(self):
+        # Copy-paste is handled with tuple data (properties, mlt_service_id)
+        return (copy.deepcopy(self.transition.properties), self.transition.info.mlt_service_id)
+
+    def do_values_copy_paste(self, copy_paste_data):
+        # Copy-paste is handled with tuple data (properties, mlt_service_id)
+        properties, mlt_service_id = copy_paste_data
+    
+        # Only allow copy paste between same types of compositors
+        if mlt_service_id == self.transition.info.mlt_service_id:
+            self.transition.properties = copy.deepcopy(properties)
+            self.transition.update_editable_mlt_properties()
+        
+        
 # -------------------------------------------------- compositor interface methods
 def load_compositors_xml(transitions):
     """
