@@ -31,6 +31,7 @@ import gui
 import guicomponents
 import guiutils
 import editorpersistance
+import editorstate
 import mlttransitions
 import renderconsumer
 import respaths
@@ -236,7 +237,7 @@ def get_two_text_panel(primary_txt, secondary_txt):
     return align
 
 def get_file_properties_panel(data):
-    media_file, img, size, length, vcodec, acodec, channels, frequency, fps = data
+    media_file, img, size, length, vcodec, acodec, channels, frequency, fps, match_profile_name, matches_current_profile = data
     
     row0 = get_two_column_box(get_bold_label(_("Name:")), Gtk.Label(label=media_file.name))
     row00 = get_two_column_box(get_bold_label(_("Path:")), Gtk.Label(label=media_file.path))
@@ -247,6 +248,8 @@ def get_file_properties_panel(data):
     row3 = get_two_column_box(get_bold_label(_("Audio Codec:")), Gtk.Label(label=acodec))
     row4 = get_two_column_box(get_bold_label(_("Audio Channels:")), Gtk.Label(label=channels))
     row5 = get_two_column_box(get_bold_label(_("Audio Sample Rate:")), Gtk.Label(label=frequency))
+    row6 = get_two_column_box(get_bold_label(_("Best Profile:")), Gtk.Label(label=match_profile_name))
+    row7 = get_two_column_box(get_bold_label(_("Matches Project Profile:")), Gtk.Label(label=matches_current_profile))
     
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(img, False, False, 0)
@@ -260,6 +263,8 @@ def get_file_properties_panel(data):
     vbox.pack_start(row3, False, False, 0)
     vbox.pack_start(row4, False, False, 0)
     vbox.pack_start(row5, False, False, 0)
+    vbox.pack_start(row6, False, False, 0)
+    vbox.pack_start(row7, False, False, 0)
     vbox.pack_start(Gtk.Label(), True, True, 0)
     
     return vbox
@@ -343,28 +348,26 @@ def get_transition_panel(trans_data):
                               None)
                               
     length_entry = Gtk.Entry()
-    length_entry.set_text(str(30))    
+    trans_length = 30
+    if editorstate.transition_length > 0: # use last invocation length if available
+        trans_length = editorstate.transition_length
+    length_entry.set_text(str(trans_length))    
     length_row = get_two_column_box(Gtk.Label(label=_("Length:")), 
                                     length_entry)
 
     filler = Gtk.Label()
     filler.set_size_request(10,10)
 
-    out_clip_label = Gtk.Label(label=_("From Clip Handle:"))
-    out_clip_value = Gtk.Label(label=trans_data["from_handle"])
+    out_clip_label = Gtk.Label(label=_("First Clip Out Handle:"))
+    out_clip_value = Gtk.Label(label=str(trans_data["from_handle"]) + _(" frame(s)"))
     
-    in_clip_label = Gtk.Label(label=_("To Clip Handle:"))
-    in_clip_value = Gtk.Label(label=trans_data["to_handle"])
+    in_clip_label = Gtk.Label(label=_("Second Clip In Handle:"))
+    in_clip_value = Gtk.Label(label=str(trans_data["to_handle"]) + _(" frame(s)"))
     
-    max_label = Gtk.Label(label=_("Max. Transition Length:"))
-    max_value = Gtk.Label(label=trans_data["max_length"])
-
     out_handle_row = get_two_column_box(out_clip_label, 
                                         out_clip_value)
     in_handle_row = get_two_column_box(in_clip_label, 
                                        in_clip_value)
-    max_row = get_two_column_box(max_label, 
-                                 max_value)
 
     # Encoding widgets
     encodings_cb = Gtk.ComboBoxText()
@@ -389,7 +392,6 @@ def get_transition_panel(trans_data):
     data_vbox = Gtk.VBox(False, 2)
     data_vbox.pack_start(out_handle_row, False, False, 0)
     data_vbox.pack_start(in_handle_row, False, False, 0)
-    data_vbox.pack_start(max_row, False, False, 0)
     
     enconding_vbox = Gtk.VBox(False, 2)
     enconding_vbox.pack_start(encodings_cb, False, False, 0)
@@ -397,8 +399,8 @@ def get_transition_panel(trans_data):
     
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(get_named_frame(_("Transition Options"),  edit_vbox), True, True, 0)
-    vbox.pack_start(get_named_frame(_("Clips info"),  data_vbox), True, True, 0)
     vbox.pack_start(get_named_frame(_("Encoding"),  enconding_vbox), True, True, 0)
+    vbox.pack_start(get_named_frame(_("Media Overlap info"),  data_vbox), True, True, 0)
 
     alignment = guiutils.set_margins(vbox, 12, 24, 12, 12)
 
@@ -419,7 +421,10 @@ def get_fade_panel(fade_data):
     color_row = get_two_column_box(color_label, color_button_box)
                               
     length_entry = Gtk.Entry()
-    length_entry.set_text(str(30))    
+    fade_length = 30
+    if editorstate.fade_length > 0: # use last invocation length if available
+        fade_length = editorstate.fade_length
+    length_entry.set_text(str(fade_length))    
     length_row = get_two_column_box(Gtk.Label(label=_("Length:")), 
                                     length_entry)
 
