@@ -27,9 +27,11 @@ import editorpersistance
 import gui
 import guiutils
 import mltprofiles
+# Jan-2017 - SvdB - To get the number of CPU cores
+import multiprocessing
 
 PREFERENCES_WIDTH = 730
-PREFERENCES_HEIGHT = 320
+PREFERENCES_HEIGHT = 440
 PREFERENCES_LEFT = 410
 
 select_thumbnail_dir_callback = None # app.py sets at start up
@@ -46,15 +48,18 @@ def preferences_dialog():
     gen_opts_panel, gen_opts_widgets = _general_options_panel(_thumbs_select_clicked, _renders_select_clicked)
     edit_prefs_panel, edit_prefs_widgets = _edit_prefs_panel()
     view_pres_panel, view_pref_widgets = _view_prefs_panel()
+    # Jan-2017 - SvdB
+    performance_panel, performance_widgets = _performance_panel()
 
     notebook = Gtk.Notebook()
     notebook.set_size_request(PREFERENCES_WIDTH, PREFERENCES_HEIGHT)
     notebook.append_page(gen_opts_panel, Gtk.Label(label=_("General")))
     notebook.append_page(edit_prefs_panel, Gtk.Label(label=_("Editing")))
     notebook.append_page(view_pres_panel, Gtk.Label(label=_("View")))
+    notebook.append_page(performance_panel, Gtk.Label(label=_("Performance")))
     guiutils.set_margins(notebook, 4, 24, 6, 0)
 
-    dialog.connect('response', _preferences_dialog_callback, (gen_opts_widgets, edit_prefs_widgets, view_pref_widgets))
+    dialog.connect('response', _preferences_dialog_callback, (gen_opts_widgets, edit_prefs_widgets, view_pref_widgets, performance_widgets))
     dialog.vbox.pack_start(notebook, True, True, 0)
     dialogutils.set_outer_margins(dialog.vbox)
     dialogutils.default_behaviour(dialog)
@@ -187,9 +192,25 @@ def _edit_prefs_panel():
     if hasattr(prefs, 'play_pause'):
         play_pause_button.set_active(prefs.play_pause)    
     
+    active = 0
+    if prefs.mouse_scroll_action_is_zoom == False:
+        active = 1
+    mouse_scroll_action = Gtk.ComboBoxText()
+    mouse_scroll_action.append_text(_("Zoom, Control to Scroll Horizontal"))
+    mouse_scroll_action.append_text(_("Scroll Horizontal, Control to Zoom"))
+    mouse_scroll_action.set_active(active)
+
+    hide_file_ext_button = Gtk.CheckButton()
+    if hasattr(prefs, 'hide_file_ext'):
+        hide_file_ext_button.set_active(prefs.hide_file_ext)
+
+    auto_center_on_updown = Gtk.CheckButton()
+    auto_center_on_updown.set_active(prefs.center_on_arrow_move)
+    
     # Layout
     row1 = _row(guiutils.get_checkbox_row_box(auto_play_in_clip_monitor, Gtk.Label(label=_("Autoplay new Clips in Clip Monitor"))))
     row2 = _row(guiutils.get_checkbox_row_box(auto_center_on_stop, Gtk.Label(label=_("Center Current Frame on Playback Stop"))))
+    row13 = _row(guiutils.get_checkbox_row_box(auto_center_on_updown, Gtk.Label(label=_("Center Current Frame after Up/Down Arrow"))))
     row4 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Graphics default length:")), gfx_length_spin, PREFERENCES_LEFT))
     row5 = _row(guiutils.get_checkbox_row_box(trim_exit_on_empty, Gtk.Label(label=_("Trim Modes exit on empty click"))))
     row6 = _row(guiutils.get_checkbox_row_box(quick_enter_trim, Gtk.Label(label=_("Quick enter Trim Modes"))))
@@ -198,25 +219,31 @@ def _edit_prefs_panel():
     row9 = _row(guiutils.get_checkbox_row_box(cover_delete, Gtk.Label(label=_("Cover Transition/Fade clips on delete if possible"))))
     # Jul-2016 - SvdB - For play_pause button
     row10 = _row(guiutils.get_checkbox_row_box(play_pause_button, Gtk.Label(label=_("Enable single Play/Pause button"))))
+    row11 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Mouse Middle Button Scroll Action")), mouse_scroll_action, PREFERENCES_LEFT))
+    row12 = _row(guiutils.get_checkbox_row_box(hide_file_ext_button, Gtk.Label(label=_("Hide file extensions when importing Clips"))))
     
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(row5, False, False, 0)
     vbox.pack_start(row6, False, False, 0)
     vbox.pack_start(row1, False, False, 0)
     vbox.pack_start(row2, False, False, 0)
+    vbox.pack_start(row13, False, False, 0)
     vbox.pack_start(row4, False, False, 0)
     vbox.pack_start(row7, False, False, 0)
     vbox.pack_start(row8, False, False, 0)
     vbox.pack_start(row9, False, False, 0)
     # Jul-2016 - SvdB - For play_pause button
     vbox.pack_start(row10, False, False, 0)
+    vbox.pack_start(row11, False, False, 0)
+    vbox.pack_start(row12, False, False, 0)
     vbox.pack_start(Gtk.Label(), True, True, 0)
 
     guiutils.set_margins(vbox, 12, 0, 12, 12)
 
     # Jul-2016 - SvdB - Added play_pause_button
     return vbox, (auto_play_in_clip_monitor, auto_center_on_stop, gfx_length_spin,
-                   trim_exit_on_empty, quick_enter_trim, remember_clip_frame, overwrite_clip_drop, cover_delete, play_pause_button)
+                  trim_exit_on_empty, quick_enter_trim, remember_clip_frame, overwrite_clip_drop, cover_delete,
+                  play_pause_button, mouse_scroll_action, hide_file_ext_button, auto_center_on_updown)
 
 def _view_prefs_panel():
     prefs = editorpersistance.prefs
@@ -228,6 +255,10 @@ def _view_prefs_panel():
     display_splash_check = Gtk.CheckButton()
     display_splash_check.set_active(prefs.display_splash_screen)
 
+    # Feb-2017 - SvdB - For full file names
+    show_full_file_names = Gtk.CheckButton()
+    show_full_file_names.set_active(prefs.show_full_file_names)
+
     buttons_combo = Gtk.ComboBoxText()
     buttons_combo.append_text(_("Glass"))
     buttons_combo.append_text(_("Simple"))
@@ -273,6 +304,8 @@ def _view_prefs_panel():
     row3 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Theme request, icons and colors:")), dark_combo, PREFERENCES_LEFT))
     row4 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Theme detection fail fallback colors:")), theme_combo, PREFERENCES_LEFT))
     row5 =  _row(guiutils.get_two_column_box(Gtk.Label(label=_("Default audio levels display:")), audio_levels_combo, PREFERENCES_LEFT))
+    # Feb-2017 - SvdB - For full file names
+    row6 =  _row(guiutils.get_checkbox_row_box(show_full_file_names, Gtk.Label(label=_("Show Full File names"))))
 
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(row00, False, False, 0)
@@ -282,11 +315,50 @@ def _view_prefs_panel():
     vbox.pack_start(row3, False, False, 0)
     vbox.pack_start(row4, False, False, 0)
     vbox.pack_start(row5, False, False, 0)
+    # Feb-2017 - SvdB - For full file names
+    vbox.pack_start(row6, False, False, 0)
     vbox.pack_start(Gtk.Label(), True, True, 0)
 
     guiutils.set_margins(vbox, 12, 0, 12, 12)
 
-    return vbox, (force_english_check, display_splash_check, buttons_combo, dark_combo, theme_combo, audio_levels_combo, window_mode_combo)
+    # Feb-2017 - SvdB - Added code for full file names
+    return vbox, (force_english_check, display_splash_check, buttons_combo, dark_combo, theme_combo, audio_levels_combo, 
+                  window_mode_combo, show_full_file_names)
+
+def _performance_panel():
+    # Jan-2017 - SvdB
+    # Add a panel for performance settings. The first setting is allowing multiple threads to render
+    # the files. This is used for the real_time parameter to mlt in renderconsumer.py.
+    # The effect depends on the computer running the program.
+    # Max. number of threads is set to number of CPU cores. Default is 1.
+    # Allow Frame Dropping should help getting real time output on low performance computers.
+    prefs = editorpersistance.prefs
+
+    # Widgets
+    spin_adj = Gtk.Adjustment(prefs.perf_render_threads, 1, multiprocessing.cpu_count(), 1)
+    perf_render_threads = Gtk.SpinButton()
+    perf_render_threads.set_adjustment(spin_adj)
+    perf_render_threads.set_numeric(True)
+
+    perf_drop_frames = Gtk.CheckButton()
+    perf_drop_frames.set_active(prefs.perf_drop_frames)
+
+    # Tooltips
+    perf_render_threads.set_tooltip_text(_("Between 1 and the number of CPU Cores"))
+    perf_drop_frames.set_tooltip_text(_("Allow Frame Dropping for real-time rendering, when needed"))
+
+    # Layout
+    row1 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Render Threads:")), perf_render_threads, PREFERENCES_LEFT))
+    row2 = _row(guiutils.get_checkbox_row_box(perf_drop_frames, Gtk.Label(label=_("Allow Frame Dropping"))))
+
+    vbox = Gtk.VBox(False, 2)
+    vbox.pack_start(row1, False, False, 0)
+    vbox.pack_start(row2, False, False, 0)
+    vbox.pack_start(Gtk.Label(), True, True, 0)
+
+    guiutils.set_margins(vbox, 12, 0, 12, 12)
+
+    return vbox, (perf_render_threads, perf_drop_frames)
 
 def _row(row_cont):
     row_cont.set_size_request(10, 26)
