@@ -105,7 +105,7 @@ class LoadThread(threading.Thread):
             editorstate.project_is_loading = False
 
         except persistance.FileProducerNotFoundError as e:
-            print "did not find file:", e
+            print "did not find a file"
             self._error_stop(dialog, ticker)
             Gdk.threads_enter()
             primary_txt = _("Media asset was missing!")
@@ -251,7 +251,6 @@ class UpdateMediaLengthsThread(threading.Thread):
         for key, media_file in PROJECT().media_files.iteritems():
             print media_file.name
             if media_file.type == appconsts.VIDEO or media_file.type == appconsts.IMAGE_SEQUENCE:
-                print media_file.name
                 Gdk.threads_enter()
                 dialog.info.set_text(media_file.name)
                 Gdk.threads_leave()
@@ -329,10 +328,10 @@ def _enable_save():
 def new_project():
     dialogs.new_project_dialog(_new_project_dialog_callback)
 
-def _new_project_dialog_callback(dialog, response_id, profile_combo, tracks_combo, 
-                                 tracks_combo_values_list):
+def _new_project_dialog_callback(dialog, response_id, profile_combo, tracks_select):
 
-    v_tracks, a_tracks = tracks_combo_values_list[tracks_combo.get_active()]
+    v_tracks, a_tracks = tracks_select.get_tracks()
+    
     if response_id == Gtk.ResponseType.ACCEPT:
         app.new_project(profile_combo.get_active(), v_tracks, a_tracks)
         dialog.destroy()
@@ -964,6 +963,7 @@ def delete_media_files(force_delete=False):
     bin_indexes.reverse()
     for i in bin_indexes:
         current_bin().file_ids.pop(i)
+    update_current_bin_files_count()
         
     # Delete from project
     for file_id in file_ids:
@@ -1226,14 +1226,14 @@ def _add_new_sequence_dialog_callback(dialog, response_id, widgets):
         dialog.destroy()
         return
     
-    name_entry, tracks_combo, open_check = widgets
+    name_entry, tracks_select, open_check = widgets
     
     # Get dialog data 
     name = name_entry.get_text()
 
     if len(name) == 0:
         name = _("sequence_") + str(PROJECT().next_seq_number)
-    v_tracks, a_tracks = appconsts.TRACK_CONFIGURATIONS[tracks_combo.get_active()]
+    v_tracks, a_tracks = tracks_select.get_tracks()
     open_right_away = open_check.get_active()
     
     # Get index for selected sequence
@@ -1317,12 +1317,12 @@ def sequence_name_edited(cell, path, new_text, user_data):
 def change_sequence_track_count():
     dialogs.tracks_count_change_dialog(_change_track_count_dialog_callback)
 
-def _change_track_count_dialog_callback(dialog, response_id, tracks_combo):
+def _change_track_count_dialog_callback(dialog, response_id, tracks_select):
     if response_id != Gtk.ResponseType.ACCEPT:
         dialog.destroy()
         return
     
-    v_tracks, a_tracks = appconsts.TRACK_CONFIGURATIONS[tracks_combo.get_active()]
+    v_tracks, a_tracks = tracks_select.get_tracks()
     dialog.destroy()
 
     cur_seq_index = PROJECT().sequences.index(PROJECT().c_seq)
