@@ -127,9 +127,14 @@ class Project:
         else: # For non-audio we need write a thumbbnail file and get file lengh while we're at it
              (icon_path, length, info) = thumbnailer.write_image(file_path)
 
+        # Hide file extension if enabled in user preferences
+        clip_name = file_name
+        if editorpersistance.prefs.hide_file_ext == True:
+            clip_name = name
+
         # Create media file object
         media_object = MediaFile(self.next_media_file_id, file_path, 
-                               file_name, media_type, length, icon_path, info)
+                                 clip_name, media_type, length, icon_path, info)
 
         self._add_media_object(media_object)
         
@@ -300,7 +305,7 @@ class MediaFile:
 
         # Set default length for graphics files
         (f_name, ext) = os.path.splitext(self.name)
-        if utils.file_extension_is_graphics_file(ext):
+        if utils.file_extension_is_graphics_file(ext) and self.type != appconsts.IMAGE_SEQUENCE:
             in_fr, out_fr, l = editorpersistance.get_graphics_default_in_out_length()
             self.mark_in = in_fr
             self.mark_out = out_fr
