@@ -35,6 +35,8 @@ REPLACEMENTS_XML_DOC = None
 HELP_DOC = None
 GPL_3_DOC = None
 TRANSLATIONS_DOC = None
+DEVELOPERS_DOC = None
+CONTRIBUTORS_DOC = None
 LOCALE_PATH = None
 ROOT_PARENT = None
 PATTERN_PRODUCER_PATH = None
@@ -48,7 +50,7 @@ def set_paths(root_path):
     WIPE_RESOURCES_PATH, PREFS_PATH, HELP_DOC, LOCALE_PATH, \
     GPL_3_DOC, ROOT_PARENT, PATTERN_PRODUCER_PATH, TRANSLATIONS_DOC, \
     LAUNCH_DIR, REPLACEMENTS_XML_DOC, GMIC_SCRIPTS_DOC,  \
-    PHANTOM_JAR, PHANTOM_DIR
+    PHANTOM_JAR, PHANTOM_DIR, DEVELOPERS_DOC, CONTRIBUTORS_DOC
     
     ROOT_PATH = root_path
     IMAGE_PATH = root_path + "/res/img/"
@@ -63,6 +65,8 @@ def set_paths(root_path):
     LOCALE_PATH = root_path + "/locale/"
     GPL_3_DOC = root_path + "/res/help/gpl3"
     TRANSLATIONS_DOC = root_path + "/res/help/translations"
+    DEVELOPERS_DOC = root_path + "/res/help/developers"
+    CONTRIBUTORS_DOC = root_path + "/res/help/contributors"
     ROOT_PARENT = ROOT_PATH.strip("Flowblade")
     PATTERN_PRODUCER_PATH = root_path + "/res/patternproducer/"
     LAUNCH_DIR = root_path + "/launch/"
