@@ -130,7 +130,7 @@ class Sequence:
         if self.master_audio_pan != NO_PAN:
             self.add_track_pan_filter(self.tractor, self.master_audio_pan)
 
-        # Create and ad gain filter
+        # Create and add gain filter
         gain_filter = mlt.Filter(self.profile, "volume")
         mltrefhold.hold_ref(gain_filter)
         gain_filter.set("gain", str(self.master_audio_gain))
@@ -599,7 +599,6 @@ class Sequence:
         self.compositors.append(compositor)
 
     def remove_compositor(self, old_compositor):
-        #edit.old_compositors.append(old_compositor)# HACK. Garbage collecting compositors causes crashes.
         try:
             self.compositors.remove(old_compositor)
         except ValueError: # has been restacked since creation, needs to looked up using destroy_id
@@ -627,6 +626,13 @@ class Sequence:
         """
         self.compositors.sort(_sort_compositors_comparator)
 
+    def get_track_compositors(self, track_index):
+        track_compositors = []
+        for comp in self.compositors:
+            if comp.transition.b_track == track_index:
+                track_compositors.append(comp)
+        return track_compositors
+            
     # -------------------------- monitor clip, trimming display, output mode and hidden track
     def display_monitor_clip(self, path, pattern_producer_data=None):
         """
