@@ -220,6 +220,11 @@ DARK_FRAME_SCALE_SELECTED_COLOR_GRAD_L = get_multiplied_grad(1, 1, FRAME_SCALE_S
 
 ICON_SELECTED_OVERLAY_COLOR = (0.8, 0.8, 1.0, 0.3)
 
+# Dash pattern used to create "LED"s
+BOX_DASH_INK = 12.0
+BOX_DASH_SKIP = 3.0
+BOX_DASHES = [BOX_DASH_INK, BOX_DASH_SKIP, BOX_DASH_INK, BOX_DASH_SKIP]
+
 FRAME_SCALE_LINES = (0, 0, 0)
 
 BG_COLOR = (0.5, 0.5, 0.55)#(0.6, 0.6, 0.65)
@@ -233,6 +238,8 @@ OVERWRITE_OVERLAY_COLOR = (0.2, 0.2, 0.2, 0.5)
 INSERT_MODE_COLOR = (0.9,0.9,0.0)
 OVERWRITE_MODE_COLOR = (0.9,0.0,0.0)
 OVERLAY_TRIM_COLOR = (0.81, 0.82, 0.3)
+BOX_BOUND_COLOR =(0.137, 0.80, 0.85)
+TRIM_MAX_RED = (1.0,0.1,0.1)
 
 POINTER_TRIANGLE_COLOR = (0.6, 0.7, 0.8, 0.7)
 SHADOW_POINTER_COLOR = (0.5, 0.5, 0.5)
@@ -544,7 +551,102 @@ def draw_overwrite_overlay(cr, data):
     _draw_mode_arrow(cr, arrow_x, y, OVERWRITE_MODE_COLOR)
     
     _draw_snap(cr, y)
-     
+
+def draw_overwrite_box_overlay(cr, data):
+    # Only draw if were moving
+    if data == None:
+        return
+    if data["action_on"] == False:
+        return
+
+    if data["box_selection_data"] == None: # mouse action selection
+        x1, y1 = data["press_point"]
+        x2, y2 = data["mouse_point"]
+
+        cr.set_line_width(2.0)
+        cr.set_source_rgb(*OVERLAY_COLOR)
+        cr.move_to(x1, y1)
+        cr.line_to(x1, y2)
+        cr.line_to(x2, y2)
+        cr.line_to(x2, y1)
+        cr.close_path()
+        cr.stroke()
+    else: # mouse action move
+        # Draw clips in draw range
+        cr.set_line_width(MOVE_CLIPS_LINE_WIDTH)
+        cr.set_source_rgb(*OVERLAY_COLOR)
+        
+        s_data = data["box_selection_data"]
+
+        # Draw moved clips
+        for i in range(0, len(s_data.track_selections)):
+            track_selection = s_data.track_selections[i]
+            y = _get_track_y(track_selection.track_id)
+            clip_start_frame = track_selection.range_frame_in - pos + data["delta"]
+            track_height = current_sequence().tracks[track_selection.track_id].height
+            
+            for i in range(0, len(track_selection.clip_lengths)):
+                clip_length = track_selection.clip_lengths[i]
+                if track_selection.clip_is_media[i] == True:
+                    scale_length = clip_length * pix_per_frame
+                    scale_in = clip_start_frame * pix_per_frame
+                    cr.rectangle(scale_in, y + 1.5, scale_length, track_height - 2.0)
+                    cr.stroke()
+                clip_start_frame += clip_length
+        
+        # Draw moved compositors
+        for comp in s_data.selected_compositors:
+            comp_in = comp.clip_in - pos + data["delta"]
+            comp_out = comp.clip_out - pos + data["delta"]
+            track = current_sequence().tracks[comp.transition.b_track]
+            y = _get_track_y(comp.transition.b_track) + track.height - COMPOSITOR_HEIGHT_OFF
+            track_height = current_sequence().tracks[comp.transition.b_track].height
+            scale_length = (comp_out - comp_in) * pix_per_frame
+            scale_in = comp_in * pix_per_frame
+            target_track = current_sequence().tracks[comp.transition.a_track]
+            target_y = _get_track_y(target_track.id) + target_track.height - COMPOSITOR_HEIGHT_OFF
+                
+            _create_compositor_cairo_path(cr, scale_in, scale_length, y, target_y)
+    
+            cr.set_source_rgb(*BOX_BOUND_COLOR)
+            cr.stroke()
+                    
+        # Draw bounding box
+        cr.set_line_width(6.0)
+        cr.set_source_rgb(*BOX_BOUND_COLOR)
+        x = (s_data.topleft_frame  - pos + data["delta"]) * pix_per_frame
+        w = s_data.width_frames * pix_per_frame
+        y = _get_track_y(s_data.topleft_track)
+        bottom_track = s_data.topleft_track - s_data.height_tracks + 1
+        y2 = _get_track_y(bottom_track) + current_sequence().tracks[bottom_track].height
+        cr.move_to(x, y)
+        cr.line_to(x + w, y)
+        cr.line_to(x + w, y2)
+        cr.line_to(x, y2)
+        cr.close_path()
+        cr.set_dash(BOX_DASHES, 0) 
+        cr.stroke()
+
+        # Draw move arrows
+        draw_x = x - 6
+        draw_y = y + (y2 - y) / 2.0
+        size = 9
+        cr.set_source_rgb(*OVERLAY_COLOR)
+        cr.move_to(draw_x, draw_y)
+        cr.line_to(draw_x, draw_y - size)
+        cr.line_to(draw_x - size, draw_y)
+        cr.line_to(draw_x, draw_y + size)
+        cr.close_path()
+        cr.fill()
+
+        draw_x = x + w + 6
+        cr.move_to(draw_x, draw_y)
+        cr.line_to(draw_x, draw_y - size)
+        cr.line_to(draw_x + size, draw_y)
+        cr.line_to(draw_x, draw_y + size)
+        cr.close_path()
+        cr.fill()
+        
 def _draw_move_overlay(cr, data, y):
     # Get data
     press_frame = data["press_frame"]
@@ -638,6 +740,9 @@ def draw_multi_overlay(cr, data):
             cr.close_path()
             cr.fill()
 
+    y = _get_track_y(current_sequence().first_video_index)
+    _draw_snap(cr, y)
+    
 def draw_two_roll_overlay(cr, data):
     edit_frame = data["edit_frame"]
     frame_x = _get_frame_x(edit_frame)
@@ -701,7 +806,8 @@ def draw_two_roll_overlay(cr, data):
     cr.stroke()
 
     _draw_kb_trim_indicator(cr, selection_frame_x, track_y)
-    
+    _draw_snap(cr, track_y)
+
 def draw_one_roll_overlay(cr, data):
     track_height = current_sequence().tracks[data["track"]].height
     track_y = _get_track_y(data["track"])
@@ -762,7 +868,62 @@ def draw_one_roll_overlay(cr, data):
     cr.stroke()
 
     _draw_kb_trim_indicator(cr, selection_frame_x, track_y)
+    _draw_snap(cr, track_y)
     
+def draw_one_roll_overlay_ripple(cr, data):
+    # Trim overlay
+    draw_one_roll_overlay(cr, data)
+    
+    # Blanks indicators
+    ripple_data = data["ripple_data"]
+    
+    cr.set_line_width(2.0)
+    cr.set_source_rgb(*OVERLAY_COLOR)
+    
+    for i in range(1, len(current_sequence().tracks) - 1):
+        offset = ripple_data.track_blank_end_offset[i-1]
+        if offset == None:
+            continue
+
+        delta = data["selected_frame"] - data["edit_frame"]
+        if data["to_side_being_edited"]:
+            indicator_frame = data["edit_frame"] - delta + offset
+        else:
+            indicator_frame = data["selected_frame"] + offset
+        indicator_x = _get_frame_x(indicator_frame)
+        
+        track_height = current_sequence().tracks[i].height
+        track_y = _get_track_y(i)
+
+        max_trim = False
+        if delta == ripple_data.max_backwards and ripple_data.track_edit_ops[i-1] == appconsts.MULTI_TRIM_REMOVE:
+            max_trim = True
+        
+        if max_trim:
+            cr.set_source_rgb(*TRIM_MAX_RED)
+        else:
+            cr.set_source_rgb(*OVERLAY_COLOR)
+    
+        cr.move_to(indicator_x, track_y)
+        cr.line_to(indicator_x, track_y + track_height)
+        cr.stroke()
+ 
+        draw_y = track_y + track_height / 2
+        if not max_trim:
+            cr.move_to(indicator_x - 2, draw_y)
+            cr.line_to(indicator_x - 2, draw_y - 5)
+            cr.line_to(indicator_x - 7, draw_y)
+            cr.line_to(indicator_x - 2, draw_y + 5)
+            cr.close_path()
+            cr.fill()
+
+        cr.move_to(indicator_x + 2, draw_y)
+        cr.line_to(indicator_x + 2, draw_y - 5)
+        cr.line_to(indicator_x + 7, draw_y)
+        cr.line_to(indicator_x + 2, draw_y + 5)
+        cr.close_path()
+        cr.fill()
+            
 def draw_slide_overlay(cr, data):
     track_height = current_sequence().tracks[data["track"]].height
     track_y = _get_track_y(data["track"])
@@ -1065,7 +1226,7 @@ class TimeLineCanvas:
         track = get_track(y)
         x = snapping.get_snapped_x(x, track, self.edit_mode_data)
             
-        self.move_listener(x, y, get_frame(x), button, state)
+        self.move_listener(x, y, get_frame(x), button, state) # -> editevent.tline_canvas_mouse_pressed(...)
         
     def _release_event(self, event):
         """
@@ -1178,7 +1339,7 @@ class TimeLineCanvas:
         # Get clip indexes for clips overlapping first and last displayed frame.
         start = track.get_clip_index_at(int(pos))
         end = track.get_clip_index_at(int(pos + width / pix_per_frame))
-
+        #print start, end
         width_frames = float(width) / pix_per_frame
 
         # Add 1 to end because range() last index exclusive 
@@ -1206,7 +1367,7 @@ class TimeLineCanvas:
                 
         # Draw clips in draw range
         for i in range(start, end):
-
+            #print "track :", track.id, "index:", i
             clip = track.clips[i]
 
             # Get clip frame values
